Creating your course in Moodle — OppiaMobile 0.5.2 documentation

# Creating your course in Moodle

If we have set up a course area for you on our Moodle server, then here are some basic instructions to help get you started. If you would like to request us to set up an area in Moodle for you to test out your course in OppiaMobile please contact us.

You should have received by email your username, password and link to your course area.

When you log into your course area you should see some example pages - these are there to help get you started and demonstrate some of the features available. You can either update or remove these if you don’t need them.

When you’re on the course homepage press the ‘turn editing on’ button in the top right then you get the options to add/edit activities/resources etc - for the videos essentially you’ll need to just to create “page resources”. There are some guidelines/info etc about creating courses here (esp about adding videos/images and translations): http://oppia-mobile.org/course-authors/.

If you’d like to see an example of how we structured and set up the Antenatal Care course you can see this at: http://moodle.digital-campus.org/course/view.php?id=166

Once you have some content etc that you’d like to test on your phone, press the ‘Export to Oppia Package’ button in the right hand column. At the end of the export output page, if it’s all exported successfully, there will be a link to download the course .zip package. So you can download this and copy it to the /sdcard/digitalcampus/download/ directory. Then when you start up the OppiaMobile app on your phone it will automatically install the course and you can see how it all looks on your phone/tablet.

Once you’re happy with how it all looks on your phone, you can upload the course to our server (http://demo.oppia-mobile.org - same username/password that you use for the OppiaMobile client app) and it’ll be available for anyone to download.

Note

Information on how to include stylesheets and javascript in your course

If you have any queries, comments or suggestions on how to improve these instructions, the course authoring process or any other aspect of OppiaMobile, please post them on the OppiaMobile Google Forum